==> sse_relay_server-1.0.7.tar.gz: sse_relay_server-1.0.7/src/sse_relay_server/brokers/_postgres.py <==
import json
from typing import AsyncGenerator

import dj_database_url
import psycopg
import structlog
from sse_starlette import ServerSentEvent
from sse_relay_server.client_tracking import count_clients

from ..config import ConfigurationError

logger = structlog.stdlib.get_logger("brokers.postgres")


class PostgresBroker:
    def __init__(self, postgres_url: str) -> None:
        self.postgres_url = postgres_url
        parsed_params = dj_database_url.parse(postgres_url)
        if parsed_params["ENGINE"] not in [
            "django.db.backends.postgresql_psycopg2",
            "django.db.backends.postgresql",
        ]:
            raise ConfigurationError("Only PostgreSQL is supported")
        self.db_params = {
            "client_encoding": "UTF8",
            "dbname": parsed_params["NAME"],
            "user": parsed_params["USER"],
            "password": parsed_params["PASSWORD"],
            "host": parsed_params["HOST"],
        }

    @count_clients
    async def listen(self, channel: str) -> AsyncGenerator[ServerSentEvent, None]:
        connection = await psycopg.AsyncConnection.connect(
            **self.db_params,
            autocommit=True,
        )

        async with connection.cursor() as cursor:
            logger.debug(f"Listening to {channel}")
            await cursor.execute(f"LISTEN {channel}")
            generator = connection.notifies()
            async for notify_message in generator:
                payload = json.loads(notify_message.payload)
                logger.debug(f"Data received from {channel}")
                yield ServerSentEvent(**payload)

    def notify(self, channel: str, sse_payload: dict) -> None:
        connection = psycopg.Connection.connect(
            **self.db_params,
            autocommit=True,
        )
        logger.debug(f"Publishing to {channel}: {sse_payload}")
        with connection.cursor() as cursor:
            cursor.execute(f"NOTIFY {channel}, '{json.dumps(sse_payload)}'")

==> sse_relay_server-1.0.14.tar.gz: sse_relay_server-1.0.14/src/sse_relay_server/brokers/_postgres.py <==
import json
from typing import AsyncGenerator

import psycopg
import structlog

from ..config import ConfigurationError
from ..sse_starlette import ServerSentEvent

logger = structlog.stdlib.get_logger("brokers.postgres")


class PostgresBroker:
    def __init__(self, postgres_url: str) -> None:
        self.postgres_url = postgres_url
        if not (
            self.postgres_url.startswith("postgres://")
            or self.postgres_url.startswith("postgresql://")
        ):
            raise ConfigurationError("Only PostgreSQL is supported")

    async def listen(self, channel: str) -> AsyncGenerator[ServerSentEvent, None]:
        connection = await psycopg.AsyncConnection.connect(
            self.postgres_url,
            autocommit=True,
        )

        async with connection.cursor() as cursor:
            logger.debug(f"Listening to {channel}")
            await cursor.execute(f"LISTEN {channel}")
            generator = connection.notifies()
            async for notify_message in generator:
                payload = json.loads(notify_message.payload)
                logger.debug(f"Data received from {channel}")
                yield ServerSentEvent(**payload)

    def notify(self, channel: str, sse_payload: dict) -> None:
        connection = psycopg.Connection.connect(
            self.postgres_url,
            autocommit=True,
        )
        logger.debug(f"Publishing to {channel}: {sse_payload}")
        with connection.cursor() as cursor:
            cursor.execute(f"NOTIFY {channel}, '{json.dumps(sse_payload)}'")
